Description Usage Details See Also
the mitools::MIcombine variant includes a 2007-specific variance adjustment. this will change in other years.
this adjustment statistic was pulled from the middle of page 8
https://www2.census.gov/econ/sbo/07/pums/2007_sbo_pums_users_guide.pdf#page=8
1 2 3 4 5 6 7 8 9 10 11 12 13 | sbo_MIcombine(x, adjustment = 1.992065)
sbo_with(sbo.svy, expr, ...)
sbo_subset(x, ...)
sbo_update(x, ...)
sbo_degf(x)
sbo_MIsvyciprop(formula, design, method = c("logit", "likelihood", "asin",
"beta", "mean", "xlogit"), level = 0.95,
df = mean(unlist(lapply(design$designs, survey::degf))), ...)
|
each of these sbo-specific functions contain a variant of some other library(survey) function that also maintains the census bureau's dual design calculation.
these functions expect both the coefficient and the variance survey objects
https://cran.r-project.org/web/packages/mitools/mitools.pdf
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.